@@ -19,7 +19,13 @@ else:
     from typing_extensions import Literal
 
 
-__all__ = ("EnvironmentStatusType", "FederationModeType", "ServiceName")
+__all__ = (
+    "EnvironmentStatusType",
+    "FederationModeType",
+    "finspaceServiceName",
+    "ServiceName",
+    "ResourceServiceName",
+)
 
 
 EnvironmentStatusType = Literal[
@@ -35,6 +41,7 @@ EnvironmentStatusType = Literal[
     "SUSPENDED",
 ]
 FederationModeType = Literal["FEDERATED", "LOCAL"]
+finspaceServiceName = Literal["finspace"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -66,6 +73,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -188,6 +196,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -336,3 +345,15 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
