@@ -14,6 +14,8 @@ Usage::
 import sys
 from typing import Dict, List, Mapping, Sequence
 
+from typing_extensions import NotRequired
+
 from .literals import EnvironmentStatusType, FederationModeType
 
 if sys.version_info >= (3, 9):
@@ -42,32 +44,19 @@ __all__ = (
     "UpdateEnvironmentResponseTypeDef",
 )
 
-_RequiredCreateEnvironmentRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateEnvironmentRequestRequestTypeDef",
+CreateEnvironmentRequestRequestTypeDef = TypedDict(
+    "CreateEnvironmentRequestRequestTypeDef",
     {
         "name": str,
+        "description": NotRequired[str],
+        "kmsKeyId": NotRequired[str],
+        "tags": NotRequired[Mapping[str, str]],
+        "federationMode": NotRequired[FederationModeType],
+        "federationParameters": NotRequired["FederationParametersTypeDef"],
+        "superuserParameters": NotRequired["SuperuserParametersTypeDef"],
+        "dataBundles": NotRequired[Sequence[str]],
     },
 )
-_OptionalCreateEnvironmentRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateEnvironmentRequestRequestTypeDef",
-    {
-        "description": str,
-        "kmsKeyId": str,
-        "tags": Mapping[str, str],
-        "federationMode": FederationModeType,
-        "federationParameters": "FederationParametersTypeDef",
-        "superuserParameters": "SuperuserParametersTypeDef",
-        "dataBundles": Sequence[str],
-    },
-    total=False,
-)
-
-
-class CreateEnvironmentRequestRequestTypeDef(
-    _RequiredCreateEnvironmentRequestRequestTypeDef, _OptionalCreateEnvironmentRequestRequestTypeDef
-):
-    pass
-
 
 CreateEnvironmentResponseTypeDef = TypedDict(
     "CreateEnvironmentResponseTypeDef",
@@ -89,33 +78,31 @@ DeleteEnvironmentRequestRequestTypeDef = TypedDict(
 EnvironmentTypeDef = TypedDict(
     "EnvironmentTypeDef",
     {
-        "name": str,
-        "environmentId": str,
-        "awsAccountId": str,
-        "status": EnvironmentStatusType,
-        "environmentUrl": str,
-        "description": str,
-        "environmentArn": str,
-        "sageMakerStudioDomainUrl": str,
-        "kmsKeyId": str,
-        "dedicatedServiceAccountId": str,
-        "federationMode": FederationModeType,
-        "federationParameters": "FederationParametersTypeDef",
+        "name": NotRequired[str],
+        "environmentId": NotRequired[str],
+        "awsAccountId": NotRequired[str],
+        "status": NotRequired[EnvironmentStatusType],
+        "environmentUrl": NotRequired[str],
+        "description": NotRequired[str],
+        "environmentArn": NotRequired[str],
+        "sageMakerStudioDomainUrl": NotRequired[str],
+        "kmsKeyId": NotRequired[str],
+        "dedicatedServiceAccountId": NotRequired[str],
+        "federationMode": NotRequired[FederationModeType],
+        "federationParameters": NotRequired["FederationParametersTypeDef"],
     },
-    total=False,
 )
 
 FederationParametersTypeDef = TypedDict(
     "FederationParametersTypeDef",
     {
-        "samlMetadataDocument": str,
-        "samlMetadataURL": str,
-        "applicationCallBackURL": str,
-        "federationURN": str,
-        "federationProviderName": str,
-        "attributeMap": Mapping[str, str],
+        "samlMetadataDocument": NotRequired[str],
+        "samlMetadataURL": NotRequired[str],
+        "applicationCallBackURL": NotRequired[str],
+        "federationURN": NotRequired[str],
+        "federationProviderName": NotRequired[str],
+        "attributeMap": NotRequired[Mapping[str, str]],
     },
-    total=False,
 )
 
 GetEnvironmentRequestRequestTypeDef = TypedDict(
@@ -136,10 +123,9 @@ GetEnvironmentResponseTypeDef = TypedDict(
 ListEnvironmentsRequestRequestTypeDef = TypedDict(
     "ListEnvironmentsRequestRequestTypeDef",
     {
-        "nextToken": str,
-        "maxResults": int,
+        "nextToken": NotRequired[str],
+        "maxResults": NotRequired[int],
     },
-    total=False,
 )
 
 ListEnvironmentsResponseTypeDef = TypedDict(
@@ -202,29 +188,16 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
-_RequiredUpdateEnvironmentRequestRequestTypeDef = TypedDict(
-    "_RequiredUpdateEnvironmentRequestRequestTypeDef",
+UpdateEnvironmentRequestRequestTypeDef = TypedDict(
+    "UpdateEnvironmentRequestRequestTypeDef",
     {
         "environmentId": str,
+        "name": NotRequired[str],
+        "description": NotRequired[str],
+        "federationMode": NotRequired[FederationModeType],
+        "federationParameters": NotRequired["FederationParametersTypeDef"],
     },
 )
-_OptionalUpdateEnvironmentRequestRequestTypeDef = TypedDict(
-    "_OptionalUpdateEnvironmentRequestRequestTypeDef",
-    {
-        "name": str,
-        "description": str,
-        "federationMode": FederationModeType,
-        "federationParameters": "FederationParametersTypeDef",
-    },
-    total=False,
-)
-
-
-class UpdateEnvironmentRequestRequestTypeDef(
-    _RequiredUpdateEnvironmentRequestRequestTypeDef, _OptionalUpdateEnvironmentRequestRequestTypeDef
-):
-    pass
-
 
 UpdateEnvironmentResponseTypeDef = TypedDict(
     "UpdateEnvironmentResponseTypeDef",
